<?php

namespace Drupal\acquia_contenthub\Event;

use Acquia\ContentHubClient\CDFDocument;
use Drupal\depcalc\DependencyStack;
use Symfony\Component\EventDispatcher\Event;

/**
 * An event for responding to failed imports.
 */
class FailedImportEvent extends Event {

  /**
   * The CDF Document.
   *
   * @var \Acquia\ContentHubClient\CDFDocument
   */
  protected $cdf;

  /**
   * The dependency stack.
   *
   * @var \Drupal\depcalc\DependencyStack
   */
  protected $stack;

  /**
   * The count of processed items.
   *
   * @var int
   */
  protected $count;

  /**
   * FailedImportEvent constructor.
   *
   * @param \Acquia\ContentHubClient\CDFDocument $cdf
   *   The CDF Document being processed during failure.
   * @param \Drupal\depcalc\DependencyStack $stack
   *   The dependency stack being populated during failure.
   * @param int $count
   *   The count of items processed before failure.
   */
  public function __construct(CDFDocument $cdf, DependencyStack $stack, $count) {
    $this->cdf = $cdf;
    $this->stack = $stack;
    $this->count = $count;
  }

  /**
   * Returns the CDF Document which failed to import.
   *
   * @return \Acquia\ContentHubClient\CDFDocument
   */
  public function getCdf(): CDFDocument {
    return $this->cdf;
  }

  /**
   * Returns the populated dependency stack.
   *
   * @return \Drupal\depcalc\DependencyStack
   */
  public function getStack(): DependencyStack {
    return $this->stack;
  }

  /**
   * Returns the count of processed items before failure.
   *
   * @return int
   */
  public function getCount(): int {
    return $this->count;
  }

}
